history: History dataset

historyR Documentation

History dataset

Description

A randomly generated relational event history dataset for testing and examples.

Usage

history

Format

A data frame that can be used for an analysis with remverse


remify documentation built on July 13, 2026, 5:08 p.m.