| randomREH | R Documentation |
A randomly generated sequence of relational events with 20 actors and 9915 events. Each event type is associated to one of the three following sentiments: conflict, competition and cooperation.
randomREH
data(randomREH) will load a list containing following objects:
edgelista data.frame that contains the random sequence of events. Columns of the edgelist are:
timethe timestamp indicating the time at which each event occurred;
actor1the name of the actor that generated the relational event;
actor2the name of the actor that received the relational event;
typethe type of the relational event.
actorsnames of actors interacting in the dynamic network.
typesnames of event types observed in the network and describing the sentiment of the interaction (conflict, competition and cooperation).
originstarting time point (t_0) prior to the first observed event (t_1), the class of this object must be the same as the one of the time column in the edgelist.
omit_dyada list where each element describes an alteration of the riskset which takes place at specific time points and for certain actors and/or types.
data(randomREH)
# actors names
randomREH$actors
# types names
randomREH$types
# run the preprocessing function reh() by supplying the loaded objects.
edgelist_reh <- remify(edgelist = randomREH$edgelist,
actors = randomREH$actors,
directed = TRUE,
ordinal = FALSE,
origin = randomREH$origin,
model = "tie")
# `edgelist_reh` is an object of class `remify`
class(edgelist_reh)
# names of objects inside `edgelist_reh`
names(edgelist_reh)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.