| .remify_durem_init | R Documentation |
remify_durem objectsCalled by remify when duration = TRUE. Normalises and
validates the duration edgelist, builds a standard remify object from
the start events (to obtain the actor dictionary and risk set structure), and
attaches a $durem slot with all duration-specific metadata.
.remify_durem_init(
edgelist,
directed = TRUE,
ordinal = FALSE,
model = "tie",
aggregate_time = 1L,
actors = NULL,
riskset = c("full", "active", "active_saturated", "manual"),
manual_riskset = NULL,
extend_riskset_by_type = FALSE,
event_type = NULL,
origin = NULL,
time_units = c("auto", "secs", "mins", "hours", "days", "weeks", "months", "years"),
attach_riskset = TRUE,
riskset_decode = c("labels", "ids", "none"),
riskset_max_decode = 200000L,
event_attributes = NULL,
ncores = 1L,
omit_dyad = NULL,
directed_end = FALSE,
type_exclusive = FALSE
)
edgelist |
the relational event history. An object of class |
directed |
logical value indicating whether events are directed ( |
ordinal |
logical value indicating whether only the order of events matters in the model ( |
model |
either |
aggregate_time |
Integer >= 1. Event-time aggregated based on unique time points.
Keeps every |
actors |
[optional] character vector of actors' names that may be observed interacting in the network. If |
riskset |
[optional] character value indicating the type of risk set to process: |
manual_riskset |
[optional] When |
extend_riskset_by_type |
logical. |
event_type |
Optional. Either If If When event types are present (via |
origin |
[optional] starting time point of the observation period (default is |
time_units |
Character string specifying the time unit for converting time values when 'edgelist$time' is of class Date or POSIXct; ignored for numeric or integer time. Default is "secs". |
attach_riskset |
Logical. If |
riskset_decode |
Character. Controls how (and whether) the included risk set
dyads are decoded and attached in
|
riskset_max_decode |
Integer. Maximum number of included dyads (i.e.,
|
event_attributes |
Optional character vector of column names in
These columns are stored as Note: |
ncores |
[optional] number of cores used in the parallelization of the processing functions. (default is |
directed_end |
Logical. |
type_exclusive |
Logical. Only relevant when
|
An object of class c("remify_durem", "remify").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.