| history | R Documentation |
A randomly generated relational event history dataset for testing and examples.
history
A data frame that can be used for an analysis with remverse
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.